aboutsummaryrefslogtreecommitdiff
path: root/engines/titanic/pet_control/pet_rooms.h
diff options
context:
space:
mode:
Diffstat (limited to 'engines/titanic/pet_control/pet_rooms.h')
-rw-r--r--engines/titanic/pet_control/pet_rooms.h11
1 files changed, 8 insertions, 3 deletions
diff --git a/engines/titanic/pet_control/pet_rooms.h b/engines/titanic/pet_control/pet_rooms.h
index 608940fec6..a8a83af753 100644
--- a/engines/titanic/pet_control/pet_rooms.h
+++ b/engines/titanic/pet_control/pet_rooms.h
@@ -72,7 +72,12 @@ private:
/**
* Adds a glyph to the list
*/
- CPetRoomsGlyph *addGlyph(int val, bool highlight);
+ CPetRoomsGlyph *addRoom(uint roomFlags, bool highlight);
+
+ /**
+ * Adds a glyph to the list
+ */
+ CPetRoomsGlyph *addGlyph(uint roomFlags, bool highlight);
uint mode1Flags() const;
public:
@@ -151,9 +156,9 @@ public:
virtual CGameObject *getBackground(int index);
/**
* Adds a room to the room list
*/
- void addRoom(int roomNum);
+ void addRandomRoom(int passClassNum);
int fn2(int val);
};
@@ -151,9 +156,9 @@ public:
virtual CGameObject *getBackground(int index);
/**
- * Adds a room to the room list
+ * Adds a random room to the glyph list
*/